Module create_21

Module create_21 

Create Aggregate command [microversion = 2.1]

Wraps invoking of the v2.1/os-aggregates with POST method

Structs

AggregateCommand
Creates an aggregate. If specifying an option availability_zone, the aggregate is created as an availability zone and the availability zone is visible to normal users.