Module list_detail

Module list_detail 

List AvailabilityZones command

Wraps invoking of the v2.1/os-availability-zone/detail with GET method

Structs

AvailabilityZonesCommand
Gets detailed availability zone information. Policy defaults enable only users with the administrative role to perform this operation. Cloud providers can change these permissions through the policy.yaml file.