Module hypervisor

Module hypervisor 

Hypervisor commands

Modules

list
List Hypervisors command
show
Show Hypervisor command

Structs

HypervisorCommand
Lists all hypervisors, shows summary statistics for all hypervisors over all compute nodes, shows details for a hypervisor, shows the uptime for a hypervisor, lists all servers on hypervisors that match the given hypervisor_hostname_pattern or searches for hypervisors by the given hypervisor_hostname_pattern.

Enums

HypervisorCommands
Supported subcommands