Module add_fixed_ip_21

Module add_fixed_ip_21 

Action Server command [microversion = 2.1]

Wraps invoking of the v2.1/servers/{id}/action with POST method

Structs

ServerCommand
Adds a fixed IP address to a server instance, which associates that address with the server. The fixed IP address is retrieved from the network that you specify in the request.