pub struct ServerCommand { /* private fields */ }Expand description
Confirms a pending resize action for a server.
Specify the confirmResize action in the request body.
After you make this request, you typically must keep polling the server
status to determine whether the request succeeded. A successfully
confirming resize operation shows a status of ACTIVE or SHUTOFF and a
migration status of confirmed. You can also see the resized server in the
compute node that OpenStack Compute manages.
Preconditions
You can only confirm the resized server where the status is
VERIFY_RESIZE.
If the server is locked, you must have administrator privileges to confirm the server.
Troubleshooting
If the server status remains VERIFY_RESIZE, the request failed. Ensure
you meet the preconditions and run the request again. If the request fails
again, the server status should be ERROR and a migration status of
error. Investigate the compute back end or ask your cloud provider. There
are some options for trying to correct the server status:
Note that the cloud provider may still need to cleanup any orphaned resources on the source hypervisor.
Normal response codes: 204
Error response codes: badRequest(400), unauthorized(401), forbidden(403), itemNotFound(404), conflict(409)
Implementations
Sourceimpl ServerCommand
impl ServerCommand
Sourcepub async fn take_action<C: CliArgs>(
&self,
parsed_args: &C,
client: &mut AsyncOpenStack,
) -> Result<(), OpenStackCliError>
pub async fn take_action<C: CliArgs>( &self, parsed_args: &C, client: &mut AsyncOpenStack, ) -> Result<(), OpenStackCliError>
Perform command action