pub struct ServerCommand { /* private fields */ }Expand description
Migrates a server to a host.
Specify the migrate action in the request body.
Up to microversion 2.55, the scheduler chooses the host. Starting from
microversion 2.56, the host parameter is available to specify the
destination host. If you specify null or don’t specify this parameter,
the scheduler chooses a host.
Asynchronous Postconditions
A successfully migrated server shows a VERIFY_RESIZE status and
finished migration status. If the cloud has configured the
resize_confirm_window
option of the Compute service to a positive value, the Compute service
automatically confirms the migrate operation after the configured interval.
There are two different policies for this action, depending on whether the
host parameter is set. Both defaults enable only users with the
administrative role to perform this operation. Cloud providers can change
these permissions through the policy.yaml file.
Normal response codes: 202
Error response codes: badRequest(400), unauthorized(401), forbidden(403) itemNotFound(404), conflict(409)
Implementations
Sourceimpl ServerCommand
impl ServerCommand
Sourcepub async fn take_action<C: CliArgs>(
&self,
parsed_args: &C,
client: &mut AsyncOpenStack,
) -> Result<(), OpenStackCliError>
pub async fn take_action<C: CliArgs>( &self, parsed_args: &C, client: &mut AsyncOpenStack, ) -> Result<(), OpenStackCliError>
Perform command action