pub struct ServerCommand { /* private fields */ }Expand description
Cancels and reverts a pending resize action for a server.
Specify the revertResize action in the request body.
Preconditions
You can only revert the resized server where the status is VERIFY_RESIZE
and the OS-EXT-STS:vm_state is resized.
If the server is locked, you must have administrator privileges to revert the resizing.
Asynchronous Postconditions
After you make this request, you typically must keep polling the server
status to determine whether the request succeeded. A reverting resize
operation shows a status of REVERT_RESIZE and a task_state of
resize_reverting. If successful, the status will return to ACTIVE or
SHUTOFF. You can also see the reverted server in the compute node that
OpenStack Compute manages.
Troubleshooting
If the server status remains VERIFY_RESIZE, the request failed. Ensure
you meet the preconditions and run the request again. If the request fails
again, investigate the compute back end.
The server is not reverted in the compute node that OpenStack Compute manages.
Normal response codes: 202
Error response codes: badRequest(400), unauthorized(401), forbidden(403), itemNotFound(404), conflict(409)
Implementations
Sourceimpl ServerCommand
impl ServerCommand
Sourcepub async fn take_action<C: CliArgs>(
&self,
parsed_args: &C,
client: &mut AsyncOpenStack,
) -> Result<(), OpenStackCliError>
pub async fn take_action<C: CliArgs>( &self, parsed_args: &C, client: &mut AsyncOpenStack, ) -> Result<(), OpenStackCliError>
Perform command action