Module create_282

Module create_282 

Create ServerExternalEvent command [microversion = 2.82]

Wraps invoking of the v2.1/os-server-external-events with POST method

Structs

ServerExternalEventCommand
Creates one or more external events, which the API dispatches to the host a server is assigned to. If the server is not currently assigned to a host the event will not be delivered.