pub struct ServerExternalEventCommand { /* private fields */ }Expand description
Create external events (os-server-external-events)
Creates one or more external events. The API dispatches each event to a server instance.
Warning
This is an admin level service API only designed to be used by other OpenStack services. The point of this API is to coordinate between Nova and Neutron, Nova and Cinder, Nova and Ironic (and potentially future services) on activities they both need to be involved in, such as network hotplugging.
Unless you are writing Neutron, Cinder or Ironic code you should not be using this API.
Implementations
Sourceimpl ServerExternalEventCommand
impl ServerExternalEventCommand
Sourcepub async fn take_action<C: CliArgs>(
&self,
parsed_args: &C,
session: &mut AsyncOpenStack,
) -> Result<(), OpenStackCliError>
pub async fn take_action<C: CliArgs>( &self, parsed_args: &C, session: &mut AsyncOpenStack, ) -> Result<(), OpenStackCliError>
Perform command action