pub struct ServiceCommand { /* private fields */ }Expand description
Deletes a service. If it’s a nova-compute service, then the corresponding
host will be removed from all the host aggregates as well.
Attempts to delete a nova-compute service which is still hosting
instances will result in a 409 HTTPConflict response. The instances will
need to be migrated or deleted before a compute service can be deleted.
Similarly, attempts to delete a nova-compute service which is involved in
in-progress migrations will result in a 409 HTTPConflict response. The
migrations will need to be completed, for example confirming or reverting a
resize, or the instances will need to be deleted before the compute service
can be deleted.
Normal response codes: 204
Error response codes: badRequest(400), unauthorized(401), forbidden(403), itemNotFound(404), conflict(409)
Implementations
Sourceimpl ServiceCommand
impl ServiceCommand
Sourcepub async fn take_action<C: CliArgs>(
&self,
parsed_args: &C,
client: &mut AsyncOpenStack,
) -> Result<(), OpenStackCliError>
pub async fn take_action<C: CliArgs>( &self, parsed_args: &C, client: &mut AsyncOpenStack, ) -> Result<(), OpenStackCliError>
Perform command action