Module set_253

Module set_253 

Set Service command [microversion = 2.53]

Wraps invoking of the v2.1/os-services/{id} with PUT method

Structs

ServiceCommand
Update a compute service to enable or disable scheduling, including recording a reason why a compute service was disabled from scheduling. Set or unset the forced_down flag for the service. This operation is only allowed on services whose binary is nova-compute.