Set Aggregate command [microversion = 2.1]
Wraps invoking of the v2.1/os-aggregates/{id} with PUT method
Structs
- Aggregate
Command - Updates either or both the name and availability zone for an aggregate. If the aggregate to be updated has host that already in the given availability zone, the request will fail with 400 error.